%global oname apns
Name:          java-apns
Version:       0.2.3
Release:       1%{?dist}
Summary:       Java Apple Push Notification Service Library
License:       BSD
URL:           http://notnoop.github.io/java-apns/
Source0:       https://github.com/notnoop/%{name}/archive/%{oname}-%{version}.tar.gz

BuildRequires: java-devel
BuildRequires: mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires: mvn(org.slf4j:slf4j-api)
BuildRequires: mvn(org.sonatype.oss:oss-parent)
# Test deps
BuildRequires: mvn(ch.qos.logback:logback-classic)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.mockito:mockito-all)
BuildRequires: maven-local

BuildArch:     noarch

%description
java-apns is a Java client for Apple Push Notification service (APNs).
The library aims to provide a highly scalable interface to the Apple
server, while still being simple and modular.

The interface aims to require very minimal code to achieve the most common
cases, but have it be re-configurable so you can even use your own networking
connections or JSON library if necessary.

Features:
  *  Easy to use, high performance APNS Service API
  *  Supports Apple Feedback service
  *  Support Enhanced Apple Push Notification
  *  Support MDM and Newstand Notifications
  *  Easy to use with Apple certificates
  *  Easy to extend and reuse
  *  Easy to integrate with dependency injection frameworks
  *  Easy to setup custom notification payloads
  *  Supports connection pooling
  *  Supports re-transmission of Notifications after error

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{oname}-%{version}

# Disable jar-with-dependencies
%pom_remove_plugin :maven-assembly-plugin
# Unavailable plugin
%pom_remove_plugin com.springsource.bundlor:com.springsource.bundlor.maven
# Use felix plugin instead of bundlor
%pom_add_plugin org.apache.felix:maven-bundle-plugin . '
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-Name>${project.groupId}</Bundle-Name>
    <Bundle-SymbolicName>${project.groupId}.${project.artifactId}</Bundle-SymbolicName>
    <Bundle-Version>${project.version}</Bundle-Version>
    <Import-Package>
      org.slf4j.*,
      com.fasterxml.jackson.*,
      javax.net.*,
    </Import-Package>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>'

# Unwanted plugin
%pom_remove_plugin :maven-source-plugin
# Disable javadoc jar
%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId = 'maven-javadoc-plugin']/pom:executions"

# java.lang.Exception: test timed out after 10000 milliseconds
rm -r src/test/java/com/notnoop/apns/integration/ApnsConnectionCacheTest.java

%build

%mvn_file :%{oname} %{oname}
%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc CHANGELOG LICENSE README.markdown

%files javadoc -f .mfiles-javadoc
%doc LICENSE

%changelog
* Mon May 12 2014 gil cattaneo <puntogil@libero.it> 0.2.3-1
- initial rpm
